==> mqtt_client-9.8.1.tar.gz: test/support/mqtt_client_test_connection_handler.dart <==
/*
 * Package : mqtt_client
 * Author : S. Hamblett <steve.hamblett@linux.com>
 * Date   : 27/06/2017
 * Copyright :  S.Hamblett
 */
import 'dart:async';
import 'package:mqtt_client/mqtt_client.dart';
import 'package:mqtt_client/mqtt_server_client.dart';

class TestConnectionHandlerNoSend extends MqttServerConnectionHandler {
  TestConnectionHandlerNoSend(var clientEventBus,
      {int? maxConnectionAttempts, socketOptions})
      : super(clientEventBus,
            maxConnectionAttempts: maxConnectionAttempts,
            socketOptions: socketOptions);

  @override
  Future<MqttClientConnectionStatus> internalConnect(
      String? hostname, int? port, MqttConnectMessage? message) {
    final completer = Completer<MqttClientConnectionStatus>();
    return completer.future;
  }

  @override
  MqttConnectionState disconnect() =>
      connectionStatus.state = MqttConnectionState.disconnected;
}

class TestConnectionHandlerSend extends MqttServerConnectionHandler {
  TestConnectionHandlerSend(var clientEventBus,
      {int? maxConnectionAttempts, socketOptions})
      : super(clientEventBus,
            maxConnectionAttempts: maxConnectionAttempts,
            socketOptions: socketOptions);

  List<MqttMessage?> sentMessages = <MqttMessage?>[];

  @override
  Future<MqttClientConnectionStatus> internalConnect(
      String? hostname, int? port, MqttConnectMessage? message) {
    final completer = Completer<MqttClientConnectionStatus>();
    return completer.future;
  }

  @override
  MqttConnectionState disconnect() =>
      connectionStatus.state = MqttConnectionState.disconnected;

  @override
  void sendMessage(MqttMessage? message) {
    print(
        'TestConnectionHandlerNoSend::send, message is ${message.toString()}');
    sentMessages.add(message);
  }
}

==> mqtt_client-10.0.3.tar.gz: test/support/mqtt_client_test_connection_handler.dart <==
/*
 * Package : mqtt_client
 * Author : S. Hamblett <steve.hamblett@linux.com>
 * Date   : 27/06/2017
 * Copyright :  S.Hamblett
 */
import 'dart:async';
import 'package:mqtt_client/mqtt_client.dart';
import 'package:mqtt_client/mqtt_server_client.dart';

class TestConnectionHandlerNoSend extends MqttServerConnectionHandler {
  TestConnectionHandlerNoSend(super.clientEventBus,
      {super.maxConnectionAttempts, required super.socketOptions});

  @override
  Future<MqttClientConnectionStatus> internalConnect(
      String? hostname, int? port, MqttConnectMessage? message) {
    final completer = Completer<MqttClientConnectionStatus>();
    return completer.future;
  }

  @override
  MqttConnectionState disconnect() =>
      connectionStatus.state = MqttConnectionState.disconnected;
}

class TestConnectionHandlerSend extends MqttServerConnectionHandler {
  TestConnectionHandlerSend(super.clientEventBus,
      {super.maxConnectionAttempts, required super.socketOptions});

  List<MqttMessage?> sentMessages = <MqttMessage?>[];

  @override
  Future<MqttClientConnectionStatus> internalConnect(
      String? hostname, int? port, MqttConnectMessage? message) {
    final completer = Completer<MqttClientConnectionStatus>();
    return completer.future;
  }

  @override
  MqttConnectionState disconnect() =>
      connectionStatus.state = MqttConnectionState.disconnected;

  @override
  void sendMessage(MqttMessage? message) {
    print(
        'TestConnectionHandlerNoSend::send, message is ${message.toString()}');
    sentMessages.add(message);
  }
}
